@@ -15,6 +15,8 @@
 from pyspark.sql.functions import pandas_udf, PandasUDFType
 from pyspark.sql.types import BooleanType
 
+from fink_filters.tester import spark_unit_tests
+
 import pandas as pd
 
 def sn_candidates_(
@@ -105,7 +107,17 @@ def sn_candidates_(
 def sn_candidates(
         cdsxmatch, snn_snia_vs_nonia, snn_sn_vs_all,
         drb, classtar, jd, jdstarthist, roid, ndethist) -> pd.Series:
-    """ Pandas UDF for sn_candidates_ """
+    """ Pandas UDF for sn_candidates_
+
+    Examples
+    ----------
+    >>> from fink_filters.utilities import apply_user_defined_filter
+    >>> df = spark.read.format('parquet').load('datatest')
+    >>> f = 'fink_filters.filter_sn_candidates.filter.sn_candidates'
+    >>> df = apply_user_defined_filter(df, f)
+    >>> print(df.count())
+    9
+    """
     series = sn_candidates_(
         cdsxmatch, snn_snia_vs_nonia, snn_sn_vs_all,
         drb, classtar, jd, jdstarthist, roid, ndethist
@@ -115,12 +127,7 @@ def sn_candidates(
 
 if __name__ == "__main__":
     """ Execute the test suite """
-    import sys
-    import doctest
-    import numpy as np
 
-    # Numpy introduced non-backward compatible change from v1.14.
-    if np.__version__ >= "1.14.0":
-        np.set_printoptions(legacy="1.13")
-
-    sys.exit(doctest.testmod()[0])
+    # Run the test suite
+    globs = globals()
+    spark_unit_tests(globs)
